%----------------------------------------------------------
% function [pp_fb,ppC_fb] = PP_FB_Only(y,deter,detrend,kern,band)
%
%   This function computes the Fixed-b
%   Phillips and Perron unit root tests:
%
%   The procedure computes both the t-value and the coefficient test
%   versions based on Frisch-Waugh type regressions.
%       
% Input:     y     ... Data vector, in R^{T \times 1}
%            deter ... Specifies deterministics:
%               -1 ... no deterministic component
%                0 ... intercept included
%                1 ... intercept and linear trend included
%          detrend ... Detrending method
%                1 ... One-step detrending
%                2 ... Two-step detrending
%            kern  ... Specifies chosen kernel function:
%                tr ... Truncated
%                ba ... Bartlett
%                pa ... Parzen
%                bo ... Bohman
%                da ... Daniell
%                qs ... Quadratic Spectral
%            band   ... M = bT (fixed-b value), in [0,1]
%           (deme   ... Demeaning of residuals (1 yes, 0 no) prior to
%                       Variance computations) 0 HARD WIRED CHOICE
% Output:  
%          pp_fb   ... Fixed b-asymptotics PP t-test statistic.
%          ppC_fb  ... Fixed b-asymptotics PP coeff. based statistic.
%
% External function: lr_var,lr_weights,jpl_detrend;
%
% TJV and MW, November 2009.
%----------------------------------------------------------
function[pp_fb,ppC_fb] = PP_FB_Only(y,deter,detrend,kern,band)
% Should the residuals be demeaned (0 = no, 1 = yes);
demeaning = 0;

[T,shouldbe1] = size(y);
pp_fb = 0;
ppC_fb = 0;

% Bandwidth:
M = band;

% Detrending type:
if detrend ==1, % Full regression and FW
    Yvec = y(2:T);
    Ylag = y(1:T-1);
    if deter == -1;
       Ytilde = Yvec;
       Ylagtilde = Ylag;
    elseif deter > -1;
       Ytilde = jpl_detrend(Yvec,deter);
       Ylagtilde = jpl_detrend(Ylag,deter);
    end;
    
elseif detrend == 2; % First detrend, then only AR(1) regression
    if deter == -1;
       Ytilde = y(2:T);
       Ylagtilde = y(1:T-1);
    elseif deter > -1;
        ydetr = jpl_detrend(y,deter);
        Ytilde = ydetr(2:T);
        Ylagtilde = ydetr(1:T-1);
    end;
    
end;

    % Regression to recover hat-alpha:
    %ahat = inv(Ylagtilde'*Ylagtilde)*Ylagtilde'*Ytilde;
    ahat = Ylagtilde\Ytilde;
    Uvec = Ytilde - Ylagtilde*ahat;
    Sigma = (1/(T-1))*Uvec'*Uvec;
    %t-value:
    t_ahat = (ahat-1)/sqrt(Sigma*inv(Ylagtilde'*Ylagtilde));
    
    % Fixed-b PP tests:
    % Computation of modified residuals:
    tildeU = Ytilde - (ahat + 0.5*Sigma*inv(T^(-1)*Ylagtilde'*Ylagtilde))*Ylagtilde;
    % Recomputation of LR-Variances: (Omega_tilde, fixed b put in here)
    [Omega_fix,Delta_fix,Sigma_fix] = lr_var(tildeU,kern,M,demeaning);
    % Fixed-b coefficient test statistic:
    ppC_fb = T*(ahat-1) - 0.5*(Omega_fix-Sigma)/(T^(-2)*Ylagtilde'*Ylagtilde);
    % Fixed-b t-statistic:
    pp_fb = sqrt(Sigma)/sqrt(Omega_fix)*t_ahat - 0.5*(Omega_fix-Sigma)*inv(sqrt(Omega_fix)*sqrt(T^(-2)*Ylagtilde'*Ylagtilde));
    
    

